@@ -66,12 +66,47 @@ def option_readme(args):
         return
     
     print(f"""
-    Changes in version 0.49.0
+    {utils.CYELLOW}Significant updates:{utils.CEND}
+
+     - Changes in version 0.49.0
        Added {utils.CYELLOW}-auto{utils.CEND} to the log parsing. This options activates the debug logs automatically for the -loguser especified. If no -loguser is specified it will do it for the user used to authenticate with the org.  
             {utils.CGREEN}InCli -logs -u DTI -tail -loguser username:onboarding@nosdti-parceiros.cs109.force.com -deletelogs -auto.{utils.CEND}
             This command will start listening for new logs for user onboarding@nosdti-parceiros.cs109.force.com in DTI and parsing them in real time. 
                 -auto will activate the debug logs automatically, so the logs are collected without any configuration in Salesforce. 
                 -delete will delete the logs from the server as they are parsed. A local copy for the 
+            {utils.CGREEN}InCli -logs -u DTI -tail -deletelogs -auto.{utils.CEND}
+            This command will start listening for new logs for the user used to authenticate with the org. -auto and -deletelogs as usual.
+
+            * Replace DTI by the correct alias for the org in your sfdx setup. 
+
+    {utils.CYELLOW}Parsed output fields:{utils.CEND}
+
+     - {utils.CGREEN}time entry{utils.CEND}: The entry time to the event, such as METHOD_ENTRY in the debug log. Helpful to search for the line in the debug log
+     - {utils.CGREEN}time exit{utils.CEND}:  The exit time for the event, such as METHOD_EXIT in the debug log. Helpful to search for the line in the debug log
+     - {utils.CGREEN}ts{utils.CEND}: an esier to read time entry. Time in miliseconds. 
+     - {utils.CGREEN}CPU{utils.CEND}: The Salesforce CPU Time. 
+            This field is set when there is a CPU time event in the debug log. This are generated by the system and we have no control when they occur. 
+            The parser will also look for DEBUG lines containing the CPU time information. The debug line needs to have the following format: "*** getCpuTime() *** Measured: CPUTime"
+                Adding this APEX line in the code will increase the accuracy of CPU Time: {utils.CGREEN}System.debug('*** getCpuTime() *** Measured: ' + Limits.getCpuTime());{utils.CEND}
+     - {utils.CGREEN}cpuD{utils.CEND}: The CPU time delta from the previous time the CPU Time was parsed. 
+     - {utils.CGREEN}Qt{utils.CEND}: Total queries performed executing the APEX program (user apex + managed pacakes apex). This field accurate. 
+     - {utils.CGREEN}Q{utils.CEND}: Total queries performed by the user APEX program. This field is almost accurate.
+     - {utils.CGREEN}Qcm{utils.CEND}: Total queries performed by the managed package. We do not have control when they appear. When it changes is accurate.
+     - {utils.CGREEN}Qe{utils.CEND}: Estimate queries performed by the managed package. This is an estimate for the manage package queries. Almost accurate. 
+     - {utils.CGREEN}type{utils.CEND}: Type of log event.
+     - {utils.CGREEN}line{utils.CEND}: the line in the APEX program. 
+     - {utils.CGREEN}wait{utils.CEND}: time elapsed from the previous event. Typically is the time consumed by the APEX program or managed package between events.  
+     - {utils.CGREEN}time{utils.CEND}: the time consumed executing the method. 
+     - {utils.CGREEN}query{utils.CEND}: the total queries consumed bu the method. 
+     - {utils.CGREEN}Call Stack{utils.CEND}:
+            Some Call Stack string present a  "for: xRepetitions line_number". 
+                - Repetitions: how many times the loop is repeated.
+                - line_number: the position in the loop
+                When there is a loop:
+                    - The {utils.CGREEN}time{utils.CEND} field is the total time consumed by the method in the loop. 
+                    - The {utils.CGREEN}wait{utils.CEND} field is the total wait time for the method in the loop. 
+    
+    Times are rounded to the closest milisecond. 
     """)
 
 def option_q(args):
@@ -306,7 +341,7 @@ def option_logs(args):
             {utils.CYELLOW}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
                 {utils.CGREEN}-loguser Id:0053O000000IHneQAG, -loguser "name:Onboarding Site Guest User", -loguser Alias:John.Doe, -loguser FirstName:Onboarding, -loguser ProfileId:00e3O000000IHneQAG{utils.CEND}
                 {utils.CLIGHT_PURPLE}Defaultable loguser{utils.CEND}: Can be set to default. {utils.CGREEN}-default:set loguser "Alias:John.Doe{utils.CEND}"
-            {utils.CYELLOW}-where X {utils.CEND}--> the where clause for a query.  
+            {utils.CYELLOW}-where X {utils.CEND}--> the where clause for a query on the ApexLog object.  
                 {utils.CGREEN}InCli -logs -loguser Alias:John.Doe -where="Status<>'Success" -last 10" {utils.CEND} --> parses the last 10 logs for user John.Doe where the status is not Success
             {utils.CYELLOW}-file {utils.CEND}--> creates 2 files for the parsed file, txt and html format. 
             {utils.CYELLOW}-limitinfo {utils.CEND}--> prints the times when the limits (CPU, SOQL) are parsed.  """
@@ -329,6 +364,7 @@ def option_logs(args):
     tail = True if '-tail' in args else False
     deletelogs = True if '-deletelogs' in args else False
     store = True if '-store' in args else False
+    store_logId = getParam(args,'-store') 
     error = True if '-error' in args else False
 
     if loguser == None:
@@ -355,7 +391,8 @@ def option_logs(args):
         'logToStore':True,
         'print_only_errors':error,
         'operation':None,
-        'auto':auto
+        'auto':auto,
+        'store_logId':store_logId
     }
 
     if tail:
@@ -371,7 +408,7 @@ def option_logs(args):
 
     elif logId != None:  #check if already downloaded        
         connectionInit(args)
-        return debugLogs.do_parse_logId(logId,parseContext)
+        return debugLogs.do_parse_logId(parseContext)
     else:
         connectionInit(args)
         return debugLogs.do_parse_logs_lastN(parseContext)
@@ -471,7 +508,7 @@ def main():
         print("ate ja")
     except Exception as e:
         utils.printException(e)
-        print(traceback.format_exc())
+       # print(traceback.format_exc())
 
         if "-debug" in sys.argv:
             print(traceback.format_exc())
