@@ -27,8 +27,34 @@ def Id(obj):
             id = id['value']
         return id
 
-def checkId(id):
+def IdF(objName,extendedF,init=None):
+    """Returns the Id for the especified extendedF in the form "fieldName:fieldValue" after querying SF.
+    - In some cases the extendedF contains the Id itself and no query is required.
+    - if extendedF is a string, and looks like an Id returns the Id, else exception
+    - if extendedF is a dictionary and contains a field Id and looks like an Id, return the Id, else an exception
+    - if extendedF is a fieldName:fieldValue, returns the query on object where fieldName=fieldValue
+    -
+    - objName (String): any SF Object name Order or Account
+    - extendedF: a String, and dictionary or a "fieldName:fieldValue"
+    - init: To validad the Id (extra checks), the first 3 numbers of the Id. In case of account is 001... in other cases is not as clear cut. A valid Id is checked based on a regex: length of the field and alphanumeric. Thus, It is not 100% error free. Init increases the accuracy. 
+    """
+    if extendedF == None:
+        return None
+    if type(extendedF) is dict:
+        extendedF = extendedF['Id']
+    ef = utils.extendedField(extendedF)
+    if ef['field'] == 'Id':
+        if checkId(ef['value']):
+            if init == None or ef['value'].startswith(init):
+                return ef['value']
+        utils.raiseException("No_Id",f"{extendedF} is not a valid Id")
+    return query.queryField(f" select Id from {objName} where {ef['field']} = '{ef['value']}' ")
+
+def checkId(id,init=None):
     #return re.search(r"[a-zA-Z0-9]{15}|[a-zA-Z0-9]{18}", id)
+    if init != None:
+        if id.startwith(init) == False:
+            return False
     return re.search(r"\b[a-z0-9]\w{4}0\w{12}|[a-z0-9]\w{4}0\w{9}\b", id)
 
 
@@ -190,18 +216,39 @@ def checkError():
                 utils.raiseException(obj['a'][0]['errorCode'],obj['a'][0]['message'])
         utils.raiseException(lc['errorCode'],lc['error'])
 
+def deleteMultiple(sobjectname,id): 
+    idList = ",".join(id)
+    logging.debug(f"deleting {sobjectname} with Id {idList}")
+    call = client.callAPI(f'/services/data/{apiVersion}/composite/sobjects?ids={idList}', method="delete")
+    try:
+        checkError()
+    except Exception as e:
+        if e.args[0]['errorCode'] == 'ENTITY_IS_DELETED':
+            client.glog().info(f"{sobjectname} with Id {id} is already deleted.")
+            return None
+        else:
+            raise e
+    return call 
+
 def delete(sobjectname,id):
     if id==None:
         return None
     if type(id) is list:
-        idList = ",".join(id)
-        logging.debug(f"deleting {sobjectname} with Id {idList}")
-        return client.callAPI(f'/services/data/{apiVersion}/composite/sobjects?ids={idList}', method="delete")
+        return deleteMultiple(sobjectname,id)
     id = Id(id)
    
     logging.debug(f"deleting {sobjectname} with Id {id}")
-    call =  client.callAPI(f'/services/data/{apiVersion}/sobjects/{sobjectname}/{id}', method="delete")
-    checkError()
+    action = f'/services/data/{apiVersion}/sobjects/{sobjectname}/{id}'
+    print(action)
+    call =  client.callAPI(action, method="delete")
+    try:
+        checkError()
+    except Exception as e:
+        if e.args[0]['errorCode'] == 'ENTITY_IS_DELETED':
+            client.glog().info(f"{sobjectname} with Id {id} is already deleted.")
+            return None
+        else:
+            raise e
     return call
 
 def listObjects():
