@@ -13,7 +13,8 @@ def _query(q,raiseEx=True,logResponse = False):
     if lc['error'] != None:
         lc['query'] = q
         if raiseEx==True:
-            utils.raiseException(lc['errorCode'],lc['error'],'query',f"{lc['errorOther']} . {q}")
+            errorOther = lc['errorOther'] if 'errorOther' in lc else ''
+            utils.raiseException(lc['errorCode'],lc['error'],'query',f"{errorOther} . {q}")
             raise ValueError(simplejson.dumps(call, indent=4))
         logging.warn(simplejson.dumps(call, indent=4))
 
