@@ -424,7 +424,8 @@ def requestRaw(url,action=None,method = 'get',parameters = {},data={},headers={}
         'data':data,
         'error':None,
         'errorCode':None,
-        'callTime':datetime.datetime.now()
+        'callTime':datetime.datetime.now(),
+        'errorOther' : ''
     }
 
     if _currentConnectionName != 'ConnectionLess':
