@@ -480,7 +480,7 @@ def computeTimes(call,name,times,_type=None):
     print (sec)
     return debugTimes
 
-def get_repeating_sequences(objs,field):
+def get_all_loops(objs,field):
 
     repeatingSequences = []
     lastX = 0
