@@ -703,7 +703,7 @@ class Test_Query(unittest.TestCase):
 
 
     def test_get_cart_items(seld):
-        restClient.init('NOSDEV')
+        restClient.init('NOSQSM')
         restClient.setLoggingLevel()
         cartId = "8013O000003izGtQAI"
 
@@ -728,7 +728,8 @@ class Test_Query(unittest.TestCase):
 
         ts = timeStats.TimeStats()
 
-        cartId = self.create_cart_with_promo('account_2','cart_3','NOS4u 100Mb + Móvel',pricelistF=pricelistF,create=False)
+        cartId = self.create_cart_with_promo('account_2','cart_3','NOS4u 100Mb + Móvel',pricelistF=pricelistF,create=True)
+        print(cartId)
         items = CPQ.getCartItems_api(cartId,price=False,validate=False)
         req1,res1 = restClient.callSave('getITems123')
         parentRecord = items['records'][0]['productGroups']['records'][0]
@@ -747,7 +748,7 @@ class Test_Query(unittest.TestCase):
         for x in range(0,1):
           ts.new()
 
-          call = CPQ.addItemstoCart_api(cartId,priceBookEntryId,parentRecord=parentRecord2,parentId=parentId,parentHierarchyPath=parentHierarchyPath,noResponseNeeded=False)
+          call = CPQ.addItemstoCart_api(cartId,priceBookEntryId,parentRecord=parentRecord,parentId=parentId,parentHierarchyPath=parentHierarchyPath,noResponseNeeded=False,price=False,validate=False)
           ts.time('postCartItem')
 
           req2,res2 = restClient.callSave("addItemstoCart_api123",logReply=True,logRequest=True)
