@@ -154,6 +154,14 @@ class Test_Main(unittest.TestCase):
             print(traceback.format_exc())
             self.assertTrue(1==2)
 
+    def test_logs_store_id(self):
+        try:
+            InCli._main(["-u","NOSDEV","-logs","-store","07L3O00000Dic7oUAB"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
     def test_logs_store_error(self):
         try:
             InCli._main(["-u","NOSDEV","-logs","-store","-error"])
@@ -208,7 +216,7 @@ class Test_Main(unittest.TestCase):
 
     def test_logs(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs"])
+            InCli._main(["-u","DTI","-logs"])
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -224,8 +232,8 @@ class Test_Main(unittest.TestCase):
 
     def test_log_ID_2(self):
         try:
-            id = '07L7a00000TO1qqEAD'
-            id = '07L3O00000DwwQKUAZ'
+            id = '07L3O00000Dic7oUAB'
+           # id = '07L7a00000TOMLDEA5'
             env = 'NOSDEV'
             #id = None
 
@@ -263,15 +271,24 @@ class Test_Main(unittest.TestCase):
 
     def test_log_ID(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","-last","100"])
+            InCli._main(["-u","NOSDEV","-logs","07L7a00000T0MTkEAN"])
         except Exception as e:
             print(e)
             print(traceback.format_exc())
 
-    def test_log_file(self):
+    def test_log_file_set_id(self):
         try:
-            res = InCli._main(["-u","NOSDEV","-logs","-inputfile",f"/Users/uormaechea/Documents/Dev/python/InCliLib/InCLipkg/test/files/07L3O00000Dgt4sUAB.log"])
-            self.assertTrue(res['lines'][-1] == '18:59:06.100 (4100507463)|CUMULATIVE_PROFILING_END')
+            id = '07L3O00000DwvxvUAB'
+            res = InCli._main(["-u","NOSDEV","-logs","-inputfile",f"/Users/uormaechea/Documents/Dev/python/InCliLib/InCLipkg/.InCli/logs/{id}.log"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
+    def test_log_file_test(self):
+        try:
+            id = '07L3O00000Dwx2RUAR'
+            res = InCli._main(["-u","NOSDEV","-logs","-inputfile",f"/Users/uormaechea/Documents/Dev/python/InCliLib/InCLipkg/.InCli/logs/{id}.log"])
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
